@@ -302,6 +302,28 @@ void KControlDoc::configWrite()
 /** Close the window */
 bool KControlDoc::queryClose ()
 {
+    if (_keducaFile) {
+        if (_keducaFile->changed()) {
+            int res = KMessageBox::warningYesNoCancel( widget(),
+            // ask the user to save
+            i18n( "The document \"%1\" has been modified.\n"
+                  "Do you want to save it?" ).arg( _keducaFile->getCurrentURL().fileName() ),
+            i18n( "Save Document?" ), KStdGuiItem::save(), KStdGuiItem::discard() );
+
+            switch (res)
+            {
+            case KMessageBox::Yes:
+                // Do not close the app if saving failed
+                return fileSave();
+                break;
+            case KMessageBox::No:
+                break;
+            case KMessageBox::Cancel:
+                return false;
+                break;
+            }
+        }
+    }
     this->configWrite();
     return( TRUE );
 }
@@ -379,15 +401,25 @@ void KControlDoc::slotDown()
 /** Save file */
 void KControlDoc::slotFileSave()
 {
-    if( !_isOpenFile )	{ slotFileSaveAs(); return; }
+    fileSave();
+}
+bool KControlDoc::fileSave()
+{
+    if( !_isOpenFile )	{ return fileSaveAs();  }
 
-    if( checkSave() ) _keducaFile->saveFile();
+    if( checkSave() ) return _keducaFile->saveFile();
+    return false;
 }
 
 /** Save As... */
 void KControlDoc::slotFileSaveAs()
 {
-    if( !checkSave() ) return;
+    fileSaveAs();
+}
+
+bool KControlDoc::fileSaveAs()
+{
+    if( !checkSave() ) return false;
 
     KFileDialog *dialog=new KFileDialog(QString::null, QString::null, this, "file dialog", true);
     dialog->setCaption( i18n("Save Document As") );
@@ -440,10 +472,15 @@ void KControlDoc::slotFileSaveAs()
             _recentFiles->addURL(newURL);
             // we saved the file, so the internal representation is now present as a file
             _isOpenFile=true;
-        }else
+            return true;
+        }else {
             kdDebug()<< "saving of file failed" <<endl;
-    }else
+            return false;
+        }
+    }else {
         kdDebug()<< "KControlDoc: no valid filename selected" <<endl;
+        return false;
+    }
 }
 
 /** Print file */
