@@ -27,7 +27,7 @@ I18N_NOOP("Form-based tests and exams");
 // INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
 
 static const char *version =
-I18N_NOOP("1.1");
+I18N_NOOP("1.1.1");
 
 
 static KCmdLineOptions options[] =
