@@ -16,7 +16,7 @@
  ***************************************************************************/
 
 #include <kaudioplayer.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "khsplash.h"
 
