@@ -181,7 +181,7 @@ config = kapp->config();
     Layout2->addItem( spacer, 0, 0 );
 
     closeButton = new QPushButton( GroupBox1, "closeButton" );
-    closeButton->setText( i18n( "Close" ) );
+    closeButton->setText( i18n( "&Close" ) );
 
     Layout2->addWidget( closeButton, 0, 1 );
 
