@@ -18,7 +18,11 @@
 #include "splashscreen.h"
 #include "kdebug.h"
 
-SplashScreen::SplashScreen(){
+SplashScreen::SplashScreen(QWidget *parent, const char *name):QFrame(parent,name,QWidget::WStyle_NoBorder | QWidget::WStyle_Customize)
+{
+	setGeometry ( QApplication::desktop()->width ()/2-160, QApplication::desktop()->height()/2-120, 302,302 );
+	setFrameStyle( QFrame::Box | QFrame::Raised );
+	setLineWidth( 1 );
 	setBackgroundPixmap(QPixmap(locate("data","kmessedwords/splash.png")));
 	QTimer::singleShot( 1000, this, SLOT(showMainWindow()) );
 }
@@ -26,11 +30,15 @@ SplashScreen::SplashScreen(){
 SplashScreen::~SplashScreen(){
 }
 
-void SplashScreen::closeEvent(QCloseEvent *){
+void SplashScreen::closeEvent(QCloseEvent *)
+{
 	exit(0);
 }
 
-void SplashScreen::showMainWindow(){
+void SplashScreen::showMainWindow()
+{
 	loadMain.show();
 	this->hide();
-}
\ No newline at end of file
+}
+
+#include "splashscreen.moc"
