@@ -8,7 +8,7 @@
 #include <kstatusbar.h>
 #include <klocale.h>
 #include <qwidget.h>
-#include <qpdevmet.h>
+#include <qpaintdevicemetrics.h>
 #include <qpainter.h>
 #undef	 GrayScale 
 //#include <qprinter.h>
