@@ -24,19 +24,10 @@ SkyObjectName::SkyObjectName( const QString &str, SkyObject *obj )
 {
 }
 
-SkyObjectNameListItem::SkyObjectNameListItem ( QListBox *parent, SkyObjectName *obj, bool useLocalConstellNames )
+SkyObjectNameListItem::SkyObjectNameListItem ( QListBox *parent, SkyObjectName *obj )
 	: QListBoxText ( parent ), object ( obj )
 {
-	if ( obj->skyObject()->type()==-1 ) { //constellation
-		if ( useLocalConstellNames ) {
-			//can't use translatedText(), because we need the i18n() comment string...
-			setText( i18n( "Constellation name (optional)", obj->text().local8Bit().data() ) );
-		} else {
-			setText ( obj->text() );
-		}
-	} else {  //all non-constellation objects
-		setText ( obj->translatedText() );
-	}
+	setText( obj->text() );
 }
 
 
