@@ -33,7 +33,7 @@
 #include <kconfig.h>
 #include <kstdaction.h>
 #include <kstartuplogo.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kstatusbar.h>
 
 // application specific includes
@@ -636,7 +636,7 @@ void KVerbosApp::slotStatusTrainedMsg(int n)
   s.setNum(n,10);
   s = i18n("trained: ") + s;
   statusBar()->changeItem(s, ID_TRAINED_MSG);
-};
+}
 
 // Gibt die Anzahl der richtig gebten Verben aus.
 void KVerbosApp::slotStatusCorrectMsg(int n)
@@ -645,7 +645,7 @@ void KVerbosApp::slotStatusCorrectMsg(int n)
   s.setNum(n,10);
   s = i18n("correct: ") + s;
   statusBar()->changeItem(s, ID_CORRECT_MSG);
-};
+}
 
 // ffnet einen Dialog mit dem neue Verben erfasst werden knnen.
 void KVerbosApp::slotEditErfassen()
