@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: CommonEntryPage.cpp,v 1.21 2002/02/08 19:24:02 arnold Exp $
+    $Id: CommonEntryPage.cpp,v 1.22 2002/04/20 12:55:48 binner Exp $
 
                        edit common properties
 
@@ -16,6 +16,9 @@
     -----------------------------------------------------------------------
 
     $Log: CommonEntryPage.cpp,v $
+    Revision 1.22  2002/04/20 12:55:48  binner
+    CVS_SILENT Capitalisation fixes.
+
     Revision 1.21  2002/02/08 19:24:02  arnold
     fixed sleeping dialog, applied patches for Tru64 unix
 
@@ -172,7 +175,7 @@ CommonEntryPage::CommonEntryPage
     connect( pronunce_line, SIGNAL(textChanged(const QString&)), SLOT(slotPronunceSelected(const QString&)) );
     connect( expr_line, SIGNAL(textChanged(const QString&)), SLOT(slotExprSelected(const QString&)) );
 
-    usage_label->setTitle(i18n("usage (area) of an expression", "&Usage Labels"));
+    usage_label->setTitle(i18n("Usage (area) of an Expression", "&Usage Labels"));
     pronunce_line->setFont(ipafont);
 
     lesson_box->setValidator (new BlockAllValidator() );
