@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_io.cpp,v 1.29.2.1 2002/04/12 10:09:28 coolo Exp $
+    $Id: kva_io.cpp,v 1.32 2002/05/09 09:17:20 arnold Exp $
 
                          i/o part of kvoctrain
 
@@ -15,7 +15,13 @@
     -----------------------------------------------------------------------
 
     $Log: kva_io.cpp,v $
-    Revision 1.29.2.1  2002/04/12 10:09:28  coolo
+    Revision 1.32  2002/05/09 09:17:20  arnold
+    fixed problem with filename handling
+
+    Revision 1.31  2002/04/20 12:55:48  binner
+    CVS_SILENT Capitalisation fixes.
+
+    Revision 1.30  2002/04/12 10:09:55  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
@@ -225,7 +231,7 @@ bool kvoctrainApp::queryExit()
   if (!save)
   {
      int exit = KMessageBox::warningYesNoCancel(this,
-               i18n("Vocabulary is modified.\n\nSave file before exit ?\n"),
+               i18n("Vocabulary is modified.\n\nSave file before exit?\n"),
                kapp->makeStdCaption(""),
                KStdGuiItem::save(), KStdGuiItem::discard());
      if (exit==KMessageBox::Yes) {
@@ -714,6 +720,7 @@ void kvoctrainApp::slotFileSave()
   saveDocProps(doc);
   doc->saveAs(this, doc->getFileName(), doc->getTitle(),
               kvoctrainDoc::automatic, separator, &paste_order);
+  addRecentFile(doc->getFileName());
   removeProgressBar();
 
   slotStatusMsg(IDS_DEFAULT);
@@ -795,9 +802,10 @@ void kvoctrainApp::slotFileSaveAs()
     commitEntryDlg(false);
 
   QString s;
+/*
   if (recent_files.count() > 0)
     s = recent_files[0];
-
+*/
   QString name = getFileName(kapp->makeStdCaption(i18n("Save Vocabulary As")),
                              s, FILTER_WPATTERN, parentWidget());
   if (!name.isEmpty() ) {
@@ -816,8 +824,6 @@ void kvoctrainApp::slotFileSaveAs()
     }
 
     if (doc) {
-      addRecentFile(name);
-
       QString format = i18n("Saving %1");
       QString msg = format.arg(name);
       slotStatusMsg(msg);
@@ -829,6 +835,7 @@ void kvoctrainApp::slotFileSaveAs()
       prepareProgressBar();
       doc->saveAs(this, name, doc->getTitle(),
                   kvoctrainDoc::automatic, separator, &paste_order);
+      addRecentFile(doc->getFileName());
       removeProgressBar();
     }
   }
