@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctraindoc.cpp,v 1.20.2.2 2002/04/12 10:09:28 coolo Exp $
+    $Id: kvoctraindoc.cpp,v 1.24 2002/05/09 09:20:10 arnold Exp $
 
                    maintain a kvoctrain document
 
@@ -16,14 +16,17 @@
     -----------------------------------------------------------------------
 
     $Log: kvoctraindoc.cpp,v $
-    Revision 1.20.2.2  2002/04/12 10:09:28  coolo
+    Revision 1.24  2002/05/09 09:20:10  arnold
+    fixed problem with filename handling
+
+    Revision 1.23  2002/04/22 19:12:15  binner
+    CVS_SILENT Capitalisation fixes.
+
+    Revision 1.22  2002/04/12 10:09:56  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
 
-    Revision 1.20.2.1  2002/04/10 12:26:51  mueller
-    we aint need no values.h here
-
     Revision 1.21  2002/04/10 12:26:19  mueller
     we aint need no values.h here
 
@@ -188,7 +191,8 @@ kvoctrainDoc::kvoctrainDoc(QObject *parent, QString filename,
       QString format = i18n("Could not open \"%1\"\n"
                             "Probably this is not a regular file or it does not exist.");
       QString msg = format.arg(mainfile);
-      KMessageBox::sorry(0, msg, kapp->makeStdCaption(i18n("I/O failure")));
+      KMessageBox::sorry(0, msg, kapp->makeStdCaption(i18n("I/O Failure")));
+      mainfile = "unknown.kvtml";
       return;
     }
 
@@ -263,8 +267,8 @@ kvoctrainDoc::kvoctrainDoc(QObject *parent, QString filename,
         }
         QString format = i18n("Could not load \"%1\"\nDo you want to try again?");
         QString msg = format.arg(mainfile);
-        int result = KMessageBox::warningContinueCancel(0, msg, 
-                                                        kapp->makeStdCaption(i18n("I/O failure")),
+        int result = KMessageBox::warningContinueCancel(0, msg,
+                                                        kapp->makeStdCaption(i18n("I/O Failure")),
                                                         i18n("&Retry"));
         if ( result == KMessageBox::Cancel ) {
           Init();
@@ -293,7 +297,7 @@ bool kvoctrainDoc::saveAs (QObject *parent, QString name, QString title,
     tmp = mainfile;
 
   if (tmp.isEmpty())
-    tmp = "outfile.kvtml";
+    tmp = "unknown.kvtml";
 
   if (ft == automatic) {
 
@@ -319,7 +323,7 @@ bool kvoctrainDoc::saveAs (QObject *parent, QString name, QString title,
     if (!f.open( IO_WriteOnly )) {               // open file for writing
       QString format = i18n("File \"%1\" is not writable, probably you don\'t have permission to do this.\n");
       QString msg = format.arg(tmp);
-      KMessageBox::error(0, msg, kapp->makeStdCaption(i18n("I/O failure")));
+      KMessageBox::error(0, msg, kapp->makeStdCaption(i18n("I/O Failure")));
       return false;
     }
 
@@ -360,8 +364,8 @@ bool kvoctrainDoc::saveAs (QObject *parent, QString name, QString title,
     if (!saved) {
       QString format = i18n("Could not save \"%1\"\nDo you want to try again?");
       QString msg = format.arg(tmp);
-      int result = KMessageBox::warningContinueCancel(0, msg, 
-                                                      kapp->makeStdCaption(i18n("I/O failure")),
+      int result = KMessageBox::warningContinueCancel(0, msg,
+                                                      kapp->makeStdCaption(i18n("I/O Failure")),
                                                       i18n("&Retry"));
       if ( result == KMessageBox::Cancel ) return false;
     }
