@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrainexpr.cpp,v 1.11.2.1 2002/04/12 10:09:28 coolo Exp $
+    $Id: kvoctrainexpr.cpp,v 1.12 2002/04/12 10:09:56 coolo Exp $
 
                    maintain a kvoctrain expression
 
@@ -17,7 +17,7 @@
     -----------------------------------------------------------------------
 
     $Log: kvoctrainexpr.cpp,v $
-    Revision 1.11.2.1  2002/04/12 10:09:28  coolo
+    Revision 1.12  2002/04/12 10:09:56  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
