@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: langset.cpp,v 1.2.4.1 2002/04/12 10:09:28 coolo Exp $
+    $Id: langset.cpp,v 1.4 2002/11/14 22:52:35 mueller Exp $
 
                       properties for a language
 
@@ -16,7 +16,10 @@
     -----------------------------------------------------------------------
 
     $Log: langset.cpp,v $
-    Revision 1.2.4.1  2002/04/12 10:09:28  coolo
+    Revision 1.4  2002/11/14 22:52:35  mueller
+    compiler warning fixes
+
+    Revision 1.3  2002/04/12 10:09:56  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
@@ -41,8 +44,6 @@
 
 
 #include "langset.h"
-#include <iostream.h>
-
 
 void LangSet::addSet (QString _shortId, QString _longId,
                       QString _PixMapFile)
