@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: LangOptPage.cpp,v 1.21 2002/02/08 19:24:03 arnold Exp $
+    $Id: LangOptPage.cpp,v 1.22 2002/07/21 04:27:09 binner Exp $
 
                   language options dialog page
 
@@ -16,6 +16,9 @@
     -----------------------------------------------------------------------
 
     $Log: LangOptPage.cpp,v $
+    Revision 1.22  2002/07/21 04:27:09  binner
+    CVS_SILENT Style guide fixes
+
     Revision 1.21  2002/02/08 19:24:03  arnold
     fixed sleeping dialog, applied patches for Tru64 unix
 
@@ -816,7 +819,7 @@ LangOptPage::LangOptPage
       b_langPixmap->setText  (i18n("No Picture Selected"));
   }
   else {
-    b_langPixmap->setText  (i18n("No Picture Selected"));
+    b_langPixmap->setText  (i18n("No Picture Selected..."));
     b_langPixmap->setEnabled(false);
   }
 
